@@ -20,24 +20,11 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 import wtforms
 from wtforms.ext.sqlalchemy.fields import QuerySelectMultipleField
 
-#
-# Flask related modules.
-#
 from flask_babel import lazy_gettext
 
-#
-# Custom modules.
-#
-import hawat.db
+from vial.forms import get_available_groups
+
 from hawat.blueprints.users.forms import BaseUserAccountForm
-from mentat.datatype.sqldb import GroupModel
-
-
-def get_available_groups():
-    """
-    Query the database for list of all available groups.
-    """
-    return hawat.db.db_query(GroupModel).order_by(GroupModel.name).all()
 
 
 class RegisterUserAccountForm(BaseUserAccountForm):
@@ -46,8 +33,7 @@ class RegisterUserAccountForm(BaseUserAccountForm):
     """
     memberships_wanted = QuerySelectMultipleField(
         lazy_gettext('Requested group memberships:'),
-        query_factory = get_available_groups,
-        allow_blank = True
+        query_factory = get_available_groups
     )
     justification = wtforms.TextAreaField(
         lazy_gettext('Justification:'),
