@@ -16,29 +16,36 @@ This module contains custom developer login form for Hawat.
 __author__ = "Honza Mach <honza.mach.ml@gmail.com>"
 
 
-#
-# Flask related modules.
-#
 import wtforms
-import flask_wtf
+from wtforms.ext.sqlalchemy.fields import QuerySelectMultipleField
 from flask_babel import lazy_gettext
 
-#
-# Custom modules.
-#
-from hawat.forms import check_login
+from vial.forms import check_login, check_unique_login, get_available_groups
+from hawat.blueprints.users.forms import BaseUserAccountForm
 
 
-class LoginForm(flask_wtf.FlaskForm):
+class RegisterUserAccountForm(BaseUserAccountForm):
     """
-    Class representing classical password authentication login form.
+    Class representing classical account registration form.
     """
     login = wtforms.StringField(
         lazy_gettext('Login:'),
         validators = [
             wtforms.validators.DataRequired(),
             wtforms.validators.Length(min = 3, max = 50),
-            check_login
+            check_login,
+            check_unique_login
+        ]
+    )
+    memberships_wanted = QuerySelectMultipleField(
+        lazy_gettext('Requested group memberships:'),
+        query_factory = get_available_groups
+    )
+    justification = wtforms.TextAreaField(
+        lazy_gettext('Justification:'),
+        validators = [
+            wtforms.validators.DataRequired(),
+            wtforms.validators.Length(min = 10, max = 500)
         ]
     )
     password = wtforms.PasswordField(
@@ -48,9 +55,10 @@ class LoginForm(flask_wtf.FlaskForm):
             wtforms.validators.Length(min = 8),
         ]
     )
-    submit = wtforms.SubmitField(
-        lazy_gettext('Login')
-    )
-    cancel = wtforms.SubmitField(
-        lazy_gettext('Cancel')
+    password2 = wtforms.PasswordField(
+        lazy_gettext('Repeat Password:'),
+        validators = [
+            wtforms.validators.DataRequired(),
+            wtforms.validators.EqualTo('password'),
+        ]
     )
