@@ -9,9 +9,6 @@
 
 
 """
-Description
------------
-
 This pluggable module provides access to database status information. The
 following information is provided:
 
@@ -55,29 +52,28 @@ __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
 
+import sys
 import datetime
 import traceback
 
-#
-# Flask related modules.
-#
+import werkzeug.routing
 import flask
 import flask_login
 from flask_babel import gettext, lazy_gettext
 from sqlalchemy import or_
 
-#
-# Custom modules.
-#
 import mentat.const
 import mentat.system
 from mentat.datatype.sqldb import UserModel, GroupModel, FilterModel, SettingsReportingModel
 
-import hawat.menu
-import hawat.acl
-import hawat.events
-from hawat.forms import ItemActionConfirmForm
-from hawat.base import RenderableView, SimpleView, PsycopgMixin, SQLAlchemyMixin, AJAXMixin, HTMLMixin, HawatBlueprint, RE_UQUERY
+import vial.menu
+import vial.acl
+from vial.app import VialBlueprint
+from vial.view import RenderableView, SimpleView
+from vial.view.mixin import HTMLMixin, AJAXMixin, SQLAlchemyMixin
+from vial.forms import ItemActionConfirmForm
+from hawat.base import PsycopgMixin
+from hawat.base import RE_UQUERY
 
 
 BLUEPRINT_NAME = 'dbstatus'
@@ -90,26 +86,22 @@ class ViewView(HTMLMixin, PsycopgMixin, SimpleView):
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ADMIN]
+    authorization = [vial.acl.PERMISSION_ADMIN]
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'view'
 
     @classmethod
     def get_view_icon(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_icon`."""
         return 'module-{}'.format(BLUEPRINT_NAME)
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Database status')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Database status')
 
     def _enrich_result_queries(self, result):
@@ -124,12 +116,11 @@ class ViewView(HTMLMixin, PsycopgMixin, SimpleView):
             record['user_id'] = user_id
             record['query_id'] = query_id
             if user_id not in cache:
-                cache[user_id] = hawat.db.db_get().session.query(UserModel).filter(UserModel.id == int(user_id)).one_or_none()
+                cache[user_id] = vial.db.db_get().session.query(UserModel).filter(UserModel.id == int(user_id)).one_or_none()
             record['user'] = cache[user_id]
         return result
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
         self.response_context.update(
             query_status_events = self._enrich_result_queries(self.get_db().queries_status()),
             database_status_events = self.get_db().database_status(),
@@ -154,7 +145,7 @@ class ViewView(HTMLMixin, PsycopgMixin, SimpleView):
             database_statistics_events = dbstatistics_events
         )
 
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'stop',
@@ -172,26 +163,22 @@ class MyQueriesView(HTMLMixin, PsycopgMixin, SimpleView):
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'queries_my'
 
     @classmethod
     def get_view_icon(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_icon`."""
         return 'module-{}'.format(BLUEPRINT_NAME)
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('My queries')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('My currently running queries')
 
     def _enrich_result_queries(self, result):
@@ -206,12 +193,11 @@ class MyQueriesView(HTMLMixin, PsycopgMixin, SimpleView):
             record['user_id'] = user_id
             record['query_id'] = query_id
             if user_id not in cache:
-                cache[user_id] = hawat.db.db_get().session.query(UserModel).filter(UserModel.id == int(user_id)).one_or_none()
+                cache[user_id] = vial.db.db_get().session.query(UserModel).filter(UserModel.id == int(user_id)).one_or_none()
             record['user'] = cache[user_id]
         return result
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
         self.response_context.update(
             query_status_events = self._enrich_result_queries(
                 self.get_db().queries_status(
@@ -222,7 +208,7 @@ class MyQueriesView(HTMLMixin, PsycopgMixin, SimpleView):
             )
         )
 
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'stop',
@@ -240,38 +226,32 @@ class QueryStatusView(AJAXMixin, PsycopgMixin, RenderableView):
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'query-status'
 
     @classmethod
     def get_view_icon(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_icon`."""
         return 'module-{}'.format(BLUEPRINT_NAME)
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Query status')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Query status')
 
     @classmethod
     def get_view_url(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_url`."""
         return flask.url_for(
             cls.get_view_endpoint(),
             item_id = kwargs['item']['query_name']
         )
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
         query_status = self.get_db().query_status(kwargs['item_id'])
         if not query_status:
             self.abort(404)
@@ -287,8 +267,8 @@ class QueryStatusView(AJAXMixin, PsycopgMixin, RenderableView):
         Mandatory interface required by the :py:func:`flask.views.View.dispatch_request`.
         Will be called by the **Flask** framework to service the request.
         """
-        user_id, query_id = self.parse_qname(item_id)
-        if flask_login.current_user.get_id() != user_id and not hawat.acl.PERMISSION_POWER.can():
+        user_id, _ = self.parse_qname(item_id)
+        if flask_login.current_user.get_id() != user_id and not vial.acl.PERMISSION_POWER.can():
             self.abort(
                 403,
                 gettext('You are not allowed to view status of this query.')
@@ -298,7 +278,7 @@ class QueryStatusView(AJAXMixin, PsycopgMixin, RenderableView):
         return self.generate_response()
 
 
-class AbstractQueryStopView(PsycopgMixin, RenderableView):
+class AbstractQueryStopView(PsycopgMixin, RenderableView):  # pylint: disable=locally-disabled,abstract-method
     """
     Application view providing ability to stop given query.
     """
@@ -306,26 +286,22 @@ class AbstractQueryStopView(PsycopgMixin, RenderableView):
 
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_icon(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_icon`."""
         return 'action-stop'
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Stop query')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Stop query')
 
     @classmethod
     def get_view_url(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_url`."""
         return flask.url_for(
             cls.get_view_endpoint(),
             item_id = kwargs['item']['query_name']
@@ -333,50 +309,48 @@ class AbstractQueryStopView(PsycopgMixin, RenderableView):
 
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
-        user_id, query_id = cls.parse_qname(kwargs['item']['query_name'])
-        return hawat.acl.PERMISSION_POWER.can() or flask_login.current_user.get_id() == user_id
+        user_id, _ = cls.parse_qname(kwargs['item']['query_name'])
+        return vial.acl.PERMISSION_POWER.can() or flask_login.current_user.get_id() == user_id
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Query <strong>%(item_id)s</strong> was successfully stopped.', item_id = str(kwargs['item']['query_name']))
+        return gettext(
+            'Query <strong>%(item_id)s</strong> was successfully stopped.',
+            item_id = flask.escape(str(kwargs['item']['query_name']))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to stop query <strong>%(item_id)s</strong>.', item_id = str(kwargs['item']['query_name']))
+        return gettext(
+            'Unable to stop query <strong>%(item_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item']['query_name']))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled stopping query <strong>%(item_id)s</strong>.', item_id = str(kwargs['item']['query_name']))
+        return gettext(
+            'Canceled stopping query <strong>%(item_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item']['query_name']))
+        )
 
     def get_url_next(self):
-        """
-        *Hook method*. Must return URL for redirection after action *success*. In
-        most cases there should be call for :py:func:`flask.url_for` function
-        somewhere in this method.
-        """
         try:
             return flask.url_for(
                 '{}.{}'.format(self.module_name, 'view')
             )
         except werkzeug.routing.BuildError:
             return flask.url_for(
-                flask.current_app.config['HAWAT_ENDPOINT_HOME']
+                flask.current_app.config['ENDPOINT_HOME']
             )
 
     def check_action_cancel(self, form, **kwargs):
         """
         Check the form for *cancel* button press and cancel the action.
         """
-        if getattr(form, hawat.const.HAWAT_FORM_ACTION_CANCEL).data:
+        if getattr(form, vial.const.FORM_ACTION_CANCEL).data:
             self.flash(
                 flask.Markup(self.get_message_cancel(**kwargs)),
-                hawat.const.HAWAT_FLASH_INFO
+                vial.const.FLASH_INFO
             )
             return self.redirect(default_url = self.get_url_next())
 
@@ -403,18 +377,18 @@ class AbstractQueryStopView(PsycopgMixin, RenderableView):
         if form.validate_on_submit():
             form_data = form.data
 
-            if form_data[hawat.const.HAWAT_FORM_ACTION_SUBMIT]:
+            if form_data[vial.const.FORM_ACTION_SUBMIT]:
                 try:
                     action_status = self.get_db().query_cancel(item_id)
                     if action_status:
                         self.flash(
                             flask.Markup(self.get_message_success(item = item)),
-                            hawat.const.HAWAT_FLASH_SUCCESS
+                            vial.const.FLASH_SUCCESS
                         )
                     else:
                         self.flash(
                             flask.Markup(self.get_message_failure(item = item)),
-                            hawat.const.HAWAT_FLASH_FAILURE
+                            vial.const.FLASH_FAILURE
                         )
                     self.get_db().commit()
                     return self.redirect(default_url = self.get_url_next())
@@ -423,7 +397,7 @@ class AbstractQueryStopView(PsycopgMixin, RenderableView):
                     self.get_db().commit()
                     self.flash(
                         flask.Markup(self.get_message_failure(item = item)),
-                        hawat.const.HAWAT_FLASH_FAILURE
+                        vial.const.FLASH_FAILURE
                     )
                     flask.current_app.log_exception_with_label(
                         traceback.TracebackException(*sys.exc_info()),
@@ -433,7 +407,13 @@ class AbstractQueryStopView(PsycopgMixin, RenderableView):
 
         self.response_context.update(
             confirm_form = form,
-            confirm_url  = flask.url_for('{}.{}'.format(self.module_name, self.get_view_name()), item_id = item_id),
+            confirm_url  = flask.url_for(
+                '{}.{}'.format(
+                    self.module_name,
+                    self.get_view_name()
+                ),
+                item_id = item_id
+            ),
             item_id      = item_id,
             item         = item
         )
@@ -448,12 +428,10 @@ class QueryStopView(HTMLMixin, AbstractQueryStopView):
     """
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'query-stop'
 
     @classmethod
     def get_view_template(cls):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.get_view_template`."""
         return '{}/query_stop.html'.format(cls.module_name)
 
 
@@ -463,7 +441,6 @@ class ApiQueryStopView(AJAXMixin, AbstractQueryStopView):
     """
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'api-query-stop'
 
 
@@ -473,33 +450,29 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ADMIN]
+    authorization = [vial.acl.PERMISSION_POWER]
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'dashboard'
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Object management')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Object management dashboards')
 
     @classmethod
     def get_view_template(cls):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.get_view_template`."""
         return '{}/dashboard.html'.format(cls.module_name)
 
     #---------------------------------------------------------------------------
 
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
+        """*Implementation* of :py:func:`vial.view.RenderableView.do_before_response`."""
         self.response_context['users_disabled'] = self.dbquery(UserModel).\
             filter(UserModel.enabled == False).\
             order_by(UserModel.createtime.desc()).\
@@ -581,13 +554,13 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
             order_by(SettingsReportingModel.createtime.desc()).\
             all()
 
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
             endpoint = 'users.show',
             hidetitle = True,
-            legend = lambda **x: lazy_gettext('View details of user account &quot;%(item)s&quot;', item = x['item'].login)
+            legend = lambda **x: lazy_gettext('View details of user account &quot;%(item)s&quot;', item = flask.escape(x['item'].login))
         )
         action_menu.add_entry(
             'submenu',
@@ -598,38 +571,38 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
             'endpoint',
             'more.update',
             endpoint = 'users.update',
-            legend = lambda **x: lazy_gettext('Update details of user account &quot;%(item)s&quot;', item = x['item'].login)
+            legend = lambda **x: lazy_gettext('Update details of user account &quot;%(item)s&quot;', item = flask.escape(x['item'].login))
         )
         action_menu.add_entry(
             'endpoint',
             'more.disable',
             endpoint = 'users.disable',
             icon = 'action-disable-user',
-            legend = lambda **x: lazy_gettext('Disable user account &quot;%(item)s&quot;', item = x['item'].login)
+            legend = lambda **x: lazy_gettext('Disable user account &quot;%(item)s&quot;', item = flask.escape(x['item'].login))
         )
         action_menu.add_entry(
             'endpoint',
             'more.enable',
             endpoint = 'users.enable',
             icon = 'action-enable-user',
-            legend = lambda **x: lazy_gettext('Enable user account &quot;%(item)s&quot;', item = x['item'].login)
+            legend = lambda **x: lazy_gettext('Enable user account &quot;%(item)s&quot;', item = flask.escape(x['item'].login))
         )
         action_menu.add_entry(
             'endpoint',
             'more.delete',
             endpoint = 'users.delete',
             icon = 'action-delete-user',
-            legend = lambda **x: lazy_gettext('Delete user account &quot;%(item)s&quot;', item = x['item'].login)
+            legend = lambda **x: lazy_gettext('Delete user account &quot;%(item)s&quot;', item = flask.escape(x['item'].login))
         )
         self.response_context['context_action_menu_user'] = action_menu
 
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
             endpoint = 'groups.show',
             hidetitle = True,
-            legend = lambda **x: lazy_gettext('View details of group &quot;%(item)s&quot;', item = str(x['item']))
+            legend = lambda **x: lazy_gettext('View details of group &quot;%(item)s&quot;', item = flask.escape(str(x['item'])))
         )
         action_menu.add_entry(
             'submenu',
@@ -640,35 +613,35 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
             'endpoint',
             'more.update',
             endpoint = 'groups.update',
-            legend = lambda **x: lazy_gettext('Update details of group &quot;%(item)s&quot;', item = str(x['item']))
+            legend = lambda **x: lazy_gettext('Update details of group &quot;%(item)s&quot;', item = flask.escape(str(x['item'])))
         )
         action_menu.add_entry(
             'endpoint',
             'more.disable',
             endpoint = 'groups.disable',
-            legend = lambda **x: lazy_gettext('Disable group &quot;%(item)s&quot;', item = str(x['item']))
+            legend = lambda **x: lazy_gettext('Disable group &quot;%(item)s&quot;', item = flask.escape(str(x['item'])))
         )
         action_menu.add_entry(
             'endpoint',
             'more.enable',
             endpoint = 'groups.enable',
-            legend = lambda **x: lazy_gettext('Enable group &quot;%(item)s&quot;', item = str(x['item']))
+            legend = lambda **x: lazy_gettext('Enable group &quot;%(item)s&quot;', item = flask.escape(str(x['item'])))
         )
         action_menu.add_entry(
             'endpoint',
             'more.delete',
             endpoint = 'groups.delete',
-            legend = lambda **x: lazy_gettext('Delete group &quot;%(item)s&quot;', item = str(x['item']))
+            legend = lambda **x: lazy_gettext('Delete group &quot;%(item)s&quot;', item = flask.escape(str(x['item'])))
         )
         self.response_context['context_action_menu_group'] = action_menu
 
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
             endpoint = 'filters.show',
             hidetitle = True,
-            legend = lambda **x: lazy_gettext('View details of reporting filter &quot;%(item)s&quot;', item = x['item'].name)
+            legend = lambda **x: lazy_gettext('View details of reporting filter &quot;%(item)s&quot;', item = flask.escape(x['item'].name))
         )
         action_menu.add_entry(
             'submenu',
@@ -679,25 +652,25 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
             'endpoint',
             'more.update',
             endpoint = 'filters.update',
-            legend = lambda **x: lazy_gettext('Update details of reporting filter &quot;%(item)s&quot;', item = x['item'].name)
+            legend = lambda **x: lazy_gettext('Update details of reporting filter &quot;%(item)s&quot;', item = flask.escape(x['item'].name))
         )
         action_menu.add_entry(
             'endpoint',
             'more.disable',
             endpoint = 'filters.disable',
-            legend = lambda **x: lazy_gettext('Disable reporting filter &quot;%(item)s&quot;', item = x['item'].name)
+            legend = lambda **x: lazy_gettext('Disable reporting filter &quot;%(item)s&quot;', item = flask.escape(x['item'].name))
         )
         action_menu.add_entry(
             'endpoint',
             'more.enable',
             endpoint = 'filters.enable',
-            legend = lambda **x: lazy_gettext('Enable reporting filter &quot;%(item)s&quot;', item = x['item'].name)
+            legend = lambda **x: lazy_gettext('Enable reporting filter &quot;%(item)s&quot;', item = flask.escape(x['item'].name))
         )
         action_menu.add_entry(
             'endpoint',
             'more.delete',
             endpoint = 'filters.delete',
-            legend = lambda **x: lazy_gettext('Delete reporting filter &quot;%(item)s&quot;', item = x['item'].name)
+            legend = lambda **x: lazy_gettext('Delete reporting filter &quot;%(item)s&quot;', item = flask.escape(x['item'].name))
         )
         self.response_context['context_action_menu_filter'] = action_menu
 
@@ -705,26 +678,14 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
 #-------------------------------------------------------------------------------
 
 
-class DatabaseStatusBlueprint(HawatBlueprint):
-    """
-    Hawat pluggable module - database status.
-    """
+class DatabaseStatusBlueprint(VialBlueprint):
+    """Pluggable module - database status overview (*dbstatus*)."""
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.HawatBlueprint.get_module_title`."""
-        return lazy_gettext('Database status overview pluggable module')
+        return lazy_gettext('Database status overview')
 
     def register_app(self, app):
-        """
-        *Callback method*. Will be called from :py:func:`hawat.base.HawatApp.register_blueprint`
-        method and can be used to customize the Flask application object. Possible
-        use cases:
-
-        * application menu customization
-
-        :param hawat.base.HawatApp app: Flask application to be customize.
-        """
         app.menu_main.add_entry(
             'view',
             'dashboards.dbstatus',
@@ -750,8 +711,9 @@ class DatabaseStatusBlueprint(HawatBlueprint):
 
 def get_blueprint():
     """
-    Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.HawatBlueprint` or :py:class:`flask.Blueprint`.
+    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
+    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    :py:class:`flask.Blueprint`.
     """
 
     hbp = DatabaseStatusBlueprint(
@@ -760,11 +722,11 @@ def get_blueprint():
         template_folder = 'templates'
     )
 
-    hbp.register_view_class(ViewView, '/{}/view'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(MyQueriesView, '/{}/query/my'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(DashboardView, '/{}/dashboard'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(QueryStatusView, '/api/{}/query/<item_id>/status'.format(BLUEPRINT_NAME))
-    hbp.register_view_class(QueryStopView, '/{}/query/<item_id>/stop'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(ViewView,         '/{}/view'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(MyQueriesView,    '/{}/query/my'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(DashboardView,    '/{}/dashboard'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(QueryStatusView,  '/api/{}/query/<item_id>/status'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(QueryStopView,    '/{}/query/<item_id>/stop'.format(BLUEPRINT_NAME))
     hbp.register_view_class(ApiQueryStopView, '/api/{}/query/<item_id>/stop'.format(BLUEPRINT_NAME))
 
     return hbp
