@@ -21,15 +21,9 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 
 import datetime
 
-#
-# Flask related modules.
-#
 import flask
 from flask_babel import lazy_gettext
 
-#
-# Custom modules.
-#
 import mentat.stats.idea
 import mentat.services.eventstorage
 from mentat.datatype.sqldb import EventStatisticsModel
@@ -37,10 +31,13 @@ from mentat.const import tr_
 
 import hawat.const
 import hawat.events
-import hawat.acl
-from hawat.base import HTMLMixin, PsycopgMixin, AJAXMixin, SQLAlchemyMixin,\
-    BaseView, BaseSearchView, ItemShowView, SimpleView, HawatBlueprint,\
-    URLParamsBuilder
+import vial.const
+import vial.acl
+from vial.app import VialBlueprint
+from vial.view import BaseView, SimpleView, BaseSearchView, ItemShowView
+from vial.view.mixin import HTMLMixin, AJAXMixin, SQLAlchemyMixin
+from vial.utils import URLParamsBuilder
+from hawat.base import PsycopgMixin
 from hawat.blueprints.events.forms import SimpleEventSearchForm, EventDashboardForm
 
 
@@ -48,32 +45,10 @@ BLUEPRINT_NAME = 'events'
 """Name of the blueprint as module global constant."""
 
 
-def _get_enums():
-    # Get lists of available options for various event search form select fields.
-    enums = {}
-    enums.update(
-        source_types    = hawat.events.get_event_source_types(),
-        target_types    = hawat.events.get_event_target_types(),
-        detectors       = hawat.events.get_event_detectors(),
-        detector_types  = hawat.events.get_event_detector_types(),
-        categories      = hawat.events.get_event_categories(),
-        severities      = hawat.events.get_event_severities(),
-        classes         = hawat.events.get_event_classes(),
-        protocols       = hawat.events.get_event_protocols(),
-        inspection_errs = hawat.events.get_event_inspection_errs()
-    )
-    enums.update(
-        host_types = sorted(list(set(enums['source_types'] + enums['target_types']))),
-    )
-    return enums
-
 def _get_search_form(request_args = None):
-    enums = _get_enums()
-    choices = {}
-    for key, vals in enums.items():
-        choices[key] = list(zip(vals, vals))
+    choices = hawat.events.get_event_form_choices()
 
-    return SimpleEventSearchForm(
+    form = SimpleEventSearchForm(
         request_args,
         meta = {'csrf': False},
         choices_source_types    = choices['source_types'],
@@ -88,6 +63,12 @@ def _get_search_form(request_args = None):
         choices_inspection_errs = choices['inspection_errs'],
     )
 
+    # In case no time bounds were set adjust them manually.
+    if request_args and not ('dt_from' in request_args or 'dt_to' in request_args or 'st_from' in request_args or 'st_to' in request_args):
+        form.dt_from.process_data(vial.forms.default_dt_with_delta())
+        form.dt_to.process_data(vial.forms.default_dt())
+
+    return form
 
 
 class AbstractSearchView(PsycopgMixin, BaseSearchView):  # pylint: disable=locally-disabled,abstract-method
@@ -97,31 +78,32 @@ class AbstractSearchView(PsycopgMixin, BaseSearchView):  # pylint: disable=local
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Search event database')
 
+    @classmethod
+    def get_view_icon(cls):
+        return 'module-{}'.format(cls.module_name)
+
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Events')
 
     @staticmethod
     def get_search_form(request_args):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.get_search_form`.
-        """
         return _get_search_form(request_args)
 
     def do_before_search(self, form_data):  # pylint: disable=locally-disabled,no-self-use,unused-argument
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.do_before_search`.
-        """
         form_data['groups'] = [item.name for item in form_data['groups']]
 
+    def do_before_response(self, **kwargs):
+        self.response_context.update(
+            quicksearch_list = self.get_quicksearch_by_time()
+        )
+
 
 class SearchView(HTMLMixin, AbstractSearchView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
@@ -141,14 +123,11 @@ class SearchView(HTMLMixin, AbstractSearchView):  # pylint: disable=locally-disa
 
     @classmethod
     def get_breadcrumbs_menu(cls):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.get_breadcrumbs_menu`.
-        """
-        breadcrumbs_menu = hawat.menu.Menu()
+        breadcrumbs_menu = vial.menu.Menu()
         breadcrumbs_menu.add_entry(
             'endpoint',
             'home',
-            endpoint = flask.current_app.config['HAWAT_ENDPOINT_HOME']
+            endpoint = flask.current_app.config['ENDPOINT_HOME']
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
@@ -159,10 +138,7 @@ class SearchView(HTMLMixin, AbstractSearchView):  # pylint: disable=locally-disa
 
     @classmethod
     def get_context_action_menu(cls):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.get_context_action_menu`.
-        """
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
@@ -187,7 +163,6 @@ class APISearchView(AJAXMixin, AbstractSearchView):  # pylint: disable=locally-d
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'apisearch'
 
 
@@ -198,24 +173,22 @@ class AbstractShowView(PsycopgMixin, ItemShowView):  # pylint: disable=locally-d
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Show event')
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Show')
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """
-        *Interface implementation* of :py:func:`hawat.base.BaseView.get_menu_legend`.
-        """
-        return lazy_gettext('View details of event &quot;%(item)s&quot;', item = kwargs['item'].get_id())
+        return lazy_gettext(
+            'View details of event &quot;%(item)s&quot;',
+            item = flask.escape(kwargs['item'].get_id())
+        )
 
 
 class ShowView(HTMLMixin, AbstractShowView):  # pylint: disable=locally-disabled,too-many-ancestors
@@ -229,10 +202,7 @@ class ShowView(HTMLMixin, AbstractShowView):  # pylint: disable=locally-disabled
 
     @classmethod
     def get_action_menu(cls):  # pylint: disable=locally-disabled,unused-argument
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.get_action_menu`.
-        """
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'download',
@@ -250,7 +220,6 @@ class APIShowView(AJAXMixin, AbstractShowView):  # pylint: disable=locally-disab
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'apishow'
 
 
@@ -262,34 +231,33 @@ class DownloadView(PsycopgMixin, BaseView):
 
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'download'
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Download event')
 
     @classmethod
     def get_view_url(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_url`."""
-        return flask.url_for(cls.get_view_endpoint(), item_id = kwargs['item'].get_id())
+        return flask.url_for(
+            cls.get_view_endpoint(),
+            item_id = kwargs['item'].get_id()
+        )
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Download')
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """
-        *Interface implementation* of :py:func:`hawat.base.BaseView.get_menu_legend`.
-        """
-        return lazy_gettext('Download event &quot;%(item)s&quot;', item = kwargs['item'].get_id())
+        return lazy_gettext(
+            'Download event &quot;%(item)s&quot;',
+            item = flask.escape(kwargs['item'].get_id())
+        )
 
     #---------------------------------------------------------------------------
 
@@ -325,47 +293,36 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_icon(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_icon`."""
         return 'module-{}'.format(BLUEPRINT_NAME)
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Events')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Overall event dashboards')
 
     @classmethod
     def get_view_template(cls):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.get_view_template`."""
         return '{}/{}.html'.format(cls.module_name, cls.get_view_name())
 
     #---------------------------------------------------------------------------
 
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return EventStatisticsModel
 
     @staticmethod
     def get_search_form(request_args):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.get_search_form`.
-        """
         return EventDashboardForm(request_args, meta = {'csrf': False})
 
     @staticmethod
     def build_query(query, model, form_args):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SQLAlchemyMixin.build_query`.
-        """
         # Adjust query based on lower time boudary selection.
         if 'dt_from' in form_args and form_args['dt_from']:
             query = query.filter(model.dt_from >= form_args['dt_from'])
@@ -377,9 +334,6 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
         return query.order_by(model.interval)
 
     def do_after_search(self, items):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.do_after_search`.
-        """
         self.logger.debug(
             "Calculating event dashboard overview from %d records.",
             len(items)
@@ -408,7 +362,6 @@ class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable
             )
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
         self.response_context.update(
             quicksearch_list = self.get_quicksearch_by_time()
         )
@@ -423,7 +376,6 @@ class DashboardView(HTMLMixin, AbstractDashboardView):  # pylint: disable=locall
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'dashboard'
 
 
@@ -436,11 +388,9 @@ class APIDashboardView(AJAXMixin, AbstractDashboardView):  # pylint: disable=loc
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'apidashboard'
 
     def process_response_context(self):
-        """*Implementation* of :py:func:`hawat.base.AJAXMixin.process_response_context`."""
         super().process_response_context()
         # Prevent certain response context keys to appear in final response.
         for key in ('items', 'quicksearch_list'):
@@ -457,48 +407,33 @@ class APIMetadataView(AJAXMixin, SimpleView):
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     methods = ['GET','POST']
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'metadata'
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Event metadata')
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
-        self.response_context.update(**_get_enums())
+        self.response_context.update(**hawat.events.get_event_enums())
 
 
 #-------------------------------------------------------------------------------
 
 
-class EventsBlueprint(HawatBlueprint):
-    """
-    Hawat pluggable module - `IDEA <https://idea.cesnet.cz/en/index>`__ event database (*events*).
-    """
+class EventsBlueprint(VialBlueprint):
+    """Pluggable module - `IDEA <https://idea.cesnet.cz/en/index>`__ event database (*events*)."""
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.HawatBlueprint.get_module_title`."""
-        return lazy_gettext('Event database')
+        return lazy_gettext('<a href="https://idea.cesnet.cz/en/index">IDEA</a> event database')
 
     def register_app(self, app):
-        """
-        *Callback method*. Will be called from :py:func:`hawat.base.HawatApp.register_blueprint`
-        method and can be used to customize the Flask application object. Possible
-        use cases:
-
-        * application menu customization
-
-        :param hawat.base.HawatApp app: Flask application to be customize.
-        """
         app.menu_main.add_entry(
             'view',
             'dashboards.{}'.format(BLUEPRINT_NAME),
@@ -524,106 +459,106 @@ class EventsBlueprint(HawatBlueprint):
 
         # Register context search actions provided by this module.
         app.set_csag(
-            hawat.const.HAWAT_CSAG_ABUSE,
+            hawat.const.CSAG_ABUSE,
             tr_('Search for abuse group <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('groups', True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_ADDRESS,
+            hawat.const.CSAG_ADDRESS,
             tr_('Search for source <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('source_addrs', True).add_kwrule('groups', True, True)
         )
         app.set_csag(
-            hawat.const.HAWAT_CSAG_ADDRESS,
+            hawat.const.CSAG_ADDRESS,
             tr_('Search for target <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('target_addrs', True).add_kwrule('groups', True, True)
         )
         app.set_csag(
-            hawat.const.HAWAT_CSAG_ADDRESS,
+            hawat.const.CSAG_ADDRESS,
             tr_('Search for host <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('host_addrs', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_CATEGORY,
+            hawat.const.CSAG_CATEGORY,
             tr_('Search for category <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('categories', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_CLASS,
+            hawat.const.CSAG_CLASS,
             tr_('Search for class <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('classes', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_DETECTOR,
+            hawat.const.CSAG_DETECTOR,
             tr_('Search for detector <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('detectors', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_DETTYPE,
+            hawat.const.CSAG_DETTYPE,
             tr_('Search for detector type <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('detector_types', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_HOSTTYPE,
+            hawat.const.CSAG_HOSTTYPE,
             tr_('Search for source type <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('source_types', True).add_kwrule('groups', True, True)
         )
         app.set_csag(
-            hawat.const.HAWAT_CSAG_HOSTTYPE,
+            hawat.const.CSAG_HOSTTYPE,
             tr_('Search for target type <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('target_types', True).add_kwrule('groups', True, True)
         )
         app.set_csag(
-            hawat.const.HAWAT_CSAG_HOSTTYPE,
+            hawat.const.CSAG_HOSTTYPE,
             tr_('Search for host type <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('host_types', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_PORT,
+            hawat.const.CSAG_PORT,
             tr_('Search for source port <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('source_ports', True).add_kwrule('groups', True, True)
         )
         app.set_csag(
-            hawat.const.HAWAT_CSAG_PORT,
+            hawat.const.CSAG_PORT,
             tr_('Search for target port <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('target_ports', True).add_kwrule('groups', True, True)
         )
         app.set_csag(
-            hawat.const.HAWAT_CSAG_PORT,
+            hawat.const.CSAG_PORT,
             tr_('Search for host port <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('host_ports', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_PROTOCOL,
+            hawat.const.CSAG_PROTOCOL,
             tr_('Search for protocol <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('protocols', True).add_kwrule('groups', True, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_SEVERITY,
+            hawat.const.CSAG_SEVERITY,
             tr_('Search for severity <strong>%(name)s</strong> in event database'),
             SearchView,
             _get_upb().add_rule('severities', True).add_kwrule('groups', True, True)
@@ -635,8 +570,9 @@ class EventsBlueprint(HawatBlueprint):
 
 def get_blueprint():
     """
-    Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.HawatBlueprint` or :py:class:`flask.Blueprint`.
+    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
+    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    :py:class:`flask.Blueprint`.
     """
 
     hbp = EventsBlueprint(
