@@ -24,99 +24,102 @@ from wtforms.ext.sqlalchemy.fields import QuerySelectMultipleField
 import flask_wtf
 from flask_babel import lazy_gettext
 
-import hawat.const
-import hawat.db
-import hawat.forms
 from mentat.datatype.sqldb import GroupModel
+import vial.const
+import vial.forms
+import vial.db
+import hawat.const
 
 
 def get_available_groups():
     """
     Query the database for list of all available groups.
     """
-    return hawat.db.db_query(GroupModel).order_by(GroupModel.name).all()
+    return vial.db.db_query(GroupModel).order_by(GroupModel.name).all()
 
 
-class SimpleEventSearchForm(hawat.forms.BaseSearchForm):
+class SimpleEventSearchForm(vial.forms.BaseSearchForm):
     """
     Class representing simple event search form.
     """
-    dt_from = hawat.forms.SmartDateTimeField(
+    dt_from = vial.forms.SmartDateTimeField(
         lazy_gettext('Detection time from:'),
         validators = [
             wtforms.validators.Optional()
         ],
-        description = lazy_gettext('Lower time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.')
+        description = lazy_gettext('Lower time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.'),
+        default = lambda: vial.forms.default_dt_with_delta(hawat.const.DEFAULT_RESULT_TIMEDELTA)
     )
-    dt_to = hawat.forms.SmartDateTimeField(
+    dt_to = vial.forms.SmartDateTimeField(
         lazy_gettext('Detection time to:'),
         validators = [
             wtforms.validators.Optional()
         ],
-        description = lazy_gettext('Upper time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.')
+        description = lazy_gettext('Upper time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.'),
+        default = vial.forms.default_dt
     )
-    st_from = hawat.forms.SmartDateTimeField(
+    st_from = vial.forms.SmartDateTimeField(
         lazy_gettext('Storage time from:'),
         validators = [
             wtforms.validators.Optional()
         ],
         description = lazy_gettext('Lower time boundary for event storage time. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event storage time is provided by Mentat system itself. It is a timestamp of the exact moment the event was stored into the database.')
     )
-    st_to = hawat.forms.SmartDateTimeField(
+    st_to = vial.forms.SmartDateTimeField(
         lazy_gettext('Storage time to:'),
         validators = [
             wtforms.validators.Optional()
         ],
         description = lazy_gettext('Upper time boundary for event storage time. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event storage time is provided by Mentat system itself. It is a timestamp of the exact moment the event was stored into the database.')
     )
-    source_addrs = hawat.forms.CommaListField(
+    source_addrs = vial.forms.CommaListField(
         lazy_gettext('Source addresses:'),
         validators = [
             wtforms.validators.Optional(),
-            hawat.forms.check_network_record_list
+            vial.forms.check_network_record_list
         ],
         widget = wtforms.widgets.TextArea(),
         description = lazy_gettext('Comma separated list of event source IP4/6 addresses, ranges or networks. In this context a source does not necessarily mean a source of the connection, but rather a source of the problem as reported by a detector. Any additional whitespace is ignored and may be used for better readability.')
     )
-    target_addrs = hawat.forms.CommaListField(
+    target_addrs = vial.forms.CommaListField(
         lazy_gettext('Target addresses:'),
         validators = [
             wtforms.validators.Optional(),
-            hawat.forms.check_network_record_list
+            vial.forms.check_network_record_list
         ],
         widget = wtforms.widgets.TextArea(),
         description = lazy_gettext('Comma separated list of event target IP4/6 addresses, ranges or networks. In this context a target does not necessarily mean a target of the connection, but rather a victim of the problem as reported by a detector. Any additional whitespace is ignored and may be used for better readability.')
     )
-    host_addrs = hawat.forms.CommaListField(
+    host_addrs = vial.forms.CommaListField(
         lazy_gettext('Host addresses:'),
         validators = [
             wtforms.validators.Optional(),
-            hawat.forms.check_network_record_list
+            vial.forms.check_network_record_list
         ],
         widget = wtforms.widgets.TextArea(),
         description = lazy_gettext('Comma separated list of event source or target IP4/6 addresses, ranges or networks. Any additional whitespace is ignored and may be used for better readability.')
     )
-    source_ports = hawat.forms.CommaListField(
+    source_ports = vial.forms.CommaListField(
         lazy_gettext('Source ports:'),
         validators = [
             wtforms.validators.Optional(),
-            hawat.forms.check_port_list
+            vial.forms.check_port_list
         ],
         description = lazy_gettext('Comma separated list of source ports as integers. In this context a source does not necessarily mean a source of the connection, but rather a source of the problem as reported by a detector. Any additional whitespace is ignored and may be used for better readability.')
     )
-    target_ports = hawat.forms.CommaListField(
+    target_ports = vial.forms.CommaListField(
         lazy_gettext('Target ports:'),
         validators = [
             wtforms.validators.Optional(),
-            hawat.forms.check_port_list
+            vial.forms.check_port_list
         ],
         description = lazy_gettext('Comma separated list of target ports as integers. In this context a target does not necessarily mean a target of the connection, but rather a victim of the problem as reported by a detector. Any additional whitespace is ignored and may be used for better readability.')
     )
-    host_ports = hawat.forms.CommaListField(
+    host_ports = vial.forms.CommaListField(
         lazy_gettext('Host ports:'),
         validators = [
             wtforms.validators.Optional(),
-            hawat.forms.check_port_list
+            vial.forms.check_port_list
         ],
         description = lazy_gettext('Comma separated list of source or target ports as integers. Any additional whitespace is ignored and may be used for better readability.')
     )
@@ -343,20 +346,21 @@ class EventDashboardForm(flask_wtf.FlaskForm):
     """
     Class representing event dashboard search form.
     """
-    dt_from = hawat.forms.SmartDateTimeField(
+    dt_from = vial.forms.SmartDateTimeField(
         lazy_gettext('From:'),
         validators = [
             wtforms.validators.Optional()
         ],
-        default = lambda: hawat.forms.default_dt_with_delta(hawat.const.HAWAT_DEFAULT_RESULT_TIMEDELTA),
-        description = lazy_gettext('Lower time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.')
+        description = lazy_gettext('Lower time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.'),
+        default = lambda: vial.forms.default_dt_with_delta(hawat.const.DEFAULT_RESULT_TIMEDELTA)
     )
-    dt_to = hawat.forms.SmartDateTimeField(
+    dt_to = vial.forms.SmartDateTimeField(
         lazy_gettext('To:'),
         validators = [
             wtforms.validators.Optional()
         ],
-        description = lazy_gettext('Upper time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.')
+        description = lazy_gettext('Upper time boundary for event detection time as provided by event detector. Timestamp is expected to be in the format <code>YYYY-MM-DD hh:mm:ss</code> and in the timezone according to the user`s preferences. Event detectors are usually outside of the control of Mentat system administrators and may sometimes emit events with invalid detection times, for example timestamps in the future.'),
+        default = vial.forms.default_dt
     )
     submit = wtforms.SubmitField(
         lazy_gettext('Search')
