@@ -9,9 +9,6 @@
 
 
 """
-Description
------------
-
 This pluggable module provides access to reporting filter management features. These
 features include:
 
@@ -30,17 +27,11 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 import sys
 import traceback
 
-#
-# Flask related modules.
-#
 import flask
 import flask_login
 import flask_principal
 from flask_babel import gettext, lazy_gettext
 
-#
-# Custom modules.
-#
 import ipranges
 import pynspect.gparser
 import pynspect.traversers
@@ -52,12 +43,12 @@ from mentat.const import REPORTING_FILTER_BASIC
 from mentat.datatype.sqldb import FilterModel, GroupModel, ItemChangeLogModel
 from mentat.idea.internal import Idea, IDEAFilterCompiler
 
-import hawat.const
-import hawat.db
+import vial.const
+import vial.db
+from vial.app import VialBlueprint
+from vial.view import RenderableView, ItemListView, ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView, ItemDeleteView, ItemEnableView, ItemDisableView
+from vial.view.mixin import HTMLMixin, SQLAlchemyMixin
 import hawat.events
-from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemListView,\
-    ItemShowView, ItemCreateView, HawatItemCreateForView, ItemUpdateView,\
-    ItemEnableView, ItemDisableView, ItemDeleteView, RenderableView, HawatBlueprint
 from hawat.blueprints.filters.forms import BaseFilterForm, AdminFilterForm, PlaygroundFilterForm
 
 
@@ -141,24 +132,21 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
 
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_POWER]
+    authorization = [vial.acl.PERMISSION_POWER]
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Filter management')
 
     #---------------------------------------------------------------------------
 
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
     @classmethod
     def get_action_menu(cls):
-        """*Implementation* of :py:func:`hawat.base.ItemListView.get_action_menu`."""
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'create',
@@ -175,8 +163,7 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
 
     @classmethod
     def get_context_action_menu(cls):
-        """*Implementation* of :py:func:`hawat.base.ItemListView.get_context_action_menu`."""
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'show',
@@ -220,38 +207,30 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
-        return lazy_gettext('View details of reporting filter &quot;%(item)s&quot;', item = kwargs['item'].name)
+        return lazy_gettext(
+            'View details of reporting filter &quot;%(item)s&quot;',
+            item = flask.escape(kwargs['item'].name)
+        )
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Show reporting filter details')
 
-    #---------------------------------------------------------------------------
-
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
         permission_mm = flask_principal.Permission(
-            hawat.acl.MembershipNeed(kwargs['item'].group.id),
-            hawat.acl.ManagementNeed(kwargs['item'].group.id)
+            vial.acl.MembershipNeed(kwargs['item'].group.id),
+            vial.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return hawat.acl.PERMISSION_POWER.can() or permission_mm.can()
+        return vial.acl.PERMISSION_POWER.can() or permission_mm.can()
 
     @classmethod
     def get_action_menu(cls):
-        """
-        Get action menu for particular item.
-        """
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'update',
@@ -280,9 +259,6 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
         return action_menu
 
     def do_before_response(self, **kwargs):
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.HawatDbmodelView.do_before_render` interface.
-        """
         item = self.response_context['item']
         filter_tree = to_tree(item.filter)
         filter_compiled = tree_compile(filter_tree)
@@ -295,7 +271,9 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
 
         if self.can_access_endpoint('filters.update', item = item) and self.has_endpoint('changelogs.search'):
             self.response_context.update(
-                context_action_menu_changelogs = self.get_endpoint_class('changelogs.search').get_context_action_menu()
+                context_action_menu_changelogs = self.get_endpoint_class(
+                    'changelogs.search'
+                ).get_context_action_menu()
             )
 
             item_changelog = self.dbsession.query(ItemChangeLogModel).\
@@ -309,7 +287,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
 
 class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
-    View for creating new reporting filters.
+    View for creating new reporting filters for any groups.
     """
     methods = ['GET','POST']
 
@@ -317,48 +295,48 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Create reporting filter')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Create new reporting filter')
 
-    #---------------------------------------------------------------------------
-
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
+    @property
+    def dbchlogmodel(self):
+        return ItemChangeLogModel
+
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
-        return hawat.acl.PERMISSION_POWER.can()
-
-    #---------------------------------------------------------------------------
+        return vial.acl.PERMISSION_POWER.can()
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to create new reporting filter for group <strong>%(parent_id)s</strong>.', parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Unable to create new reporting filter for group <strong>%(parent_id)s</strong>.',
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled creating new reporting filter for group <strong>%(parent_id)s</strong>.', parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Canceled creating new reporting filter for group <strong>%(parent_id)s</strong>.',
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
-    def get_item_form():
-        """*Implementation* of :py:func:`hawat.base.ItemCreateView.get_item_form`."""
+    def get_item_form(item):
         detectors  = hawat.events.get_event_detectors()
         categories = hawat.events.get_event_categories()
 
@@ -368,15 +346,9 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
         )
 
     def do_before_action(self, item):  # pylint: disable=locally-disabled,no-self-use,unused-argument
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.ItemActionView.do_before_action` interface.
-        """
         process_rule(item)
 
     def do_before_response(self, **kwargs):
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.HawatDbmodelView.do_before_render` interface.
-        """
         item = self.response_context.get('item', None)
         if item:
             filter_tree = to_tree(item.filter)
@@ -386,83 +358,85 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
             )
 
 
-class CreateForView(HTMLMixin, SQLAlchemyMixin, HawatItemCreateForView):  # pylint: disable=locally-disabled,too-many-ancestors
+class CreateForView(HTMLMixin, SQLAlchemyMixin, ItemCreateForView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
-    View for creating new reporting filters.
+    View for creating new reporting filters for given groups.
     """
     methods = ['GET','POST']
 
     authentication = True
 
+    module_name_par = 'groups'
+
     @classmethod
     def get_view_icon(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_icon`."""
         return 'module-{}'.format(BLUEPRINT_NAME)
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Create reporting filter')
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """
-        *Interface implementation* of :py:func:`hawat.base.BaseView.get_menu_legend`.
-        """
-        return lazy_gettext('Create reporting filter for group &quot;%(item)s&quot;', item = str(kwargs['item']))
+        return lazy_gettext(
+            'Create reporting filter for group &quot;%(item)s&quot;',
+            item = flask.escape(str(kwargs['item']))
+        )
 
     @classmethod
     def get_view_url(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_url`."""
-        return flask.url_for(cls.get_view_endpoint(), parent_id = kwargs['item'].id)
+        return flask.url_for(
+            cls.get_view_endpoint(),
+            parent_id = kwargs['item'].id
+        )
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Create new reporting filter for group')
 
-    #---------------------------------------------------------------------------
-
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
     @property
     def dbmodel_par(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return GroupModel
 
+    @property
+    def dbchlogmodel(self):
+        return ItemChangeLogModel
+
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
         permission_m = flask_principal.Permission(
-            hawat.acl.ManagementNeed(kwargs['item'].id)
+            vial.acl.ManagementNeed(kwargs['item'].id)
         )
-        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
-
-    #---------------------------------------------------------------------------
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.', item_id = str(kwargs['item']), parent_id = str(kwargs['parent']))
+        return gettext(
+            'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully created.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['parent']))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to create new reporting filter for group <strong>%(parent_id)s</strong>.', parent_id = str(kwargs['parent']))
+        return gettext(
+            'Unable to create new reporting filter for group <strong>%(parent_id)s</strong>.',
+            parent_id = flask.escape(str(kwargs['parent']))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled creating new reporting filter for group <strong>%(parent_id)s</strong>.', parent_id = str(kwargs['parent']))
+        return gettext(
+            'Canceled creating new reporting filter for group <strong>%(parent_id)s</strong>.',
+            parent_id = flask.escape(str(kwargs['parent']))
+        )
 
     @staticmethod
-    def get_item_form():
-        """*Implementation* of :py:func:`hawat.base.ItemCreateView.get_item_form`."""
+    def get_item_form(item):
         detectors  = hawat.events.get_event_detectors()
         categories = hawat.events.get_event_categories()
 
@@ -473,21 +447,12 @@ class CreateForView(HTMLMixin, SQLAlchemyMixin, HawatItemCreateForView):  # pyli
 
     @staticmethod
     def add_parent_to_item(item, parent):
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.HawatItemCreateForView.add_parent_to_item` interface.
-        """
         item.group = parent
 
     def do_before_action(self, item):  # pylint: disable=locally-disabled,no-self-use,unused-argument
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.ItemActionView.do_before_action` interface.
-        """
         process_rule(item)
 
     def do_before_response(self, **kwargs):
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.HawatDbmodelView.do_before_render` interface.
-        """
         item = self.response_context.get('item', None)
         if item:
             filter_tree = to_tree(item.filter)
@@ -507,51 +472,56 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
-        return lazy_gettext('Update details of reporting filter &quot;%(item)s&quot;', item = kwargs['item'].name)
+        return lazy_gettext(
+            'Update details of reporting filter &quot;%(item)s&quot;',
+            item = flask.escape(kwargs['item'].name)
+        )
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Update reporting filter details')
 
-    #---------------------------------------------------------------------------
-
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
+    @property
+    def dbchlogmodel(self):
+        return ItemChangeLogModel
+
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
         permission_m = flask_principal.Permission(
-            hawat.acl.ManagementNeed(kwargs['item'].group.id)
+            vial.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
-
-    #---------------------------------------------------------------------------
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully updated.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully updated.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to update reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Unable to update reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled updating reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Canceled updating reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_item_form(item):
-        """*Implementation* of :py:func:`hawat.base.ItemUpdateView.get_item_form`."""
         detectors  = hawat.events.get_event_detectors()
         categories = hawat.events.get_event_categories()
 
@@ -570,15 +540,9 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
         )
 
     def do_before_action(self, item):  # pylint: disable=locally-disabled,no-self-use,unused-argument
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.ItemActionView.do_before_action` interface.
-        """
         process_rule(item)
 
     def do_before_response(self, **kwargs):
-        """
-        *Hook method*. Implementation of :py:func:`hawat.base.HawatDbmodelView.do_before_render` interface.
-        """
         item = self.response_context['item']
         filter_tree = to_tree(item.filter)
         self.response_context.update(
@@ -589,7 +553,7 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
 
 class EnableView(HTMLMixin, SQLAlchemyMixin, ItemEnableView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
-    View for enabling existing groups.
+    View for enabling existing reporting filters.
     """
     methods = ['GET','POST']
 
@@ -597,47 +561,54 @@ class EnableView(HTMLMixin, SQLAlchemyMixin, ItemEnableView):  # pylint: disable
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
-        return lazy_gettext('Enable reporting filter &quot;%(item)s&quot;', item = kwargs['item'].name)
-
-    #---------------------------------------------------------------------------
+        return lazy_gettext(
+            'Enable reporting filter &quot;%(item)s&quot;',
+            item = flask.escape(kwargs['item'].name)
+        )
 
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
+    @property
+    def dbchlogmodel(self):
+        return ItemChangeLogModel
+
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
         permission_m = flask_principal.Permission(
-            hawat.acl.ManagementNeed(kwargs['item'].group.id)
+            vial.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
-
-    #---------------------------------------------------------------------------
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully enabled.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully enabled.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to enable reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Unable to enable reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled enabling reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Canceled enabling reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
 
 class DisableView(HTMLMixin, SQLAlchemyMixin, ItemDisableView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
-    View for deleting existing user accounts.
+    View for disabling existing reporting filters.
     """
     methods = ['GET','POST']
 
@@ -645,42 +616,51 @@ class DisableView(HTMLMixin, SQLAlchemyMixin, ItemDisableView):  # pylint: disab
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
-        return lazy_gettext('Disable reporting filter &quot;%(item)s&quot;', item = kwargs['item'].name)
+        return lazy_gettext(
+            'Disable reporting filter &quot;%(item)s&quot;',
+            item = flask.escape(kwargs['item'].name)
+        )
 
     #---------------------------------------------------------------------------
 
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
+    @property
+    def dbchlogmodel(self):
+        return ItemChangeLogModel
+
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
         permission_m = flask_principal.Permission(
-            hawat.acl.ManagementNeed(kwargs['item'].group.id)
+            vial.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
-
-    #---------------------------------------------------------------------------
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully disabled.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully disabled.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to disable reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Unable to disable reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled disabling reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Canceled disabling reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
 
 class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable=locally-disabled,too-many-ancestors
@@ -693,42 +673,49 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
-        return lazy_gettext('Delete reporting filter &quot;%(item)s&quot;', item = kwargs['item'].name)
-
-    #---------------------------------------------------------------------------
+        return lazy_gettext(
+            'Delete reporting filter &quot;%(item)s&quot;',
+            item = flask.escape(kwargs['item'].name)
+        )
 
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return FilterModel
 
+    @property
+    def dbchlogmodel(self):
+        return ItemChangeLogModel
+
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        Perform access authorization for current user to particular item.
-        """
         permission_m = flask_principal.Permission(
-            hawat.acl.ManagementNeed(kwargs['item'].group.id)
+            vial.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return hawat.acl.PERMISSION_POWER.can() or permission_m.can()
-
-    #---------------------------------------------------------------------------
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully and permanently deleted.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong> was successfully and permanently deleted.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to permanently delete reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Unable to permanently delete reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled deleting reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.', item_id = str(kwargs['item']), parent_id = str(kwargs['item'].group))
+        return gettext(
+            'Canceled deleting reporting filter <strong>%(item_id)s</strong> for group <strong>%(parent_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item'])),
+            parent_id = flask.escape(str(kwargs['item'].group))
+        )
 
 
 class PlaygroundView(HTMLMixin, RenderableView):
@@ -741,39 +728,31 @@ class PlaygroundView(HTMLMixin, RenderableView):
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'playground'
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Filter playground')
 
     @classmethod
     def get_view_icon(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_icon`."""
         return 'playground'
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Reporting filter playground')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Reporting filter rule playground')
 
     @classmethod
     def get_breadcrumbs_menu(cls):
-        """
-        Get breadcrumbs menu.
-        """
-        breadcrumbs_menu = hawat.menu.Menu()
+        breadcrumbs_menu = vial.menu.Menu()
         breadcrumbs_menu.add_entry(
             'endpoint',
             'home',
-            endpoint = flask.current_app.config['HAWAT_ENDPOINT_HOME']
+            endpoint = flask.current_app.config['ENDPOINT_HOME']
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
@@ -787,10 +766,6 @@ class PlaygroundView(HTMLMixin, RenderableView):
         )
         return breadcrumbs_menu
 
-
-    #---------------------------------------------------------------------------
-
-
     def dispatch_request(self):
         """
         Mandatory interface required by the :py:func:`flask.views.View.dispatch_request`.
@@ -826,7 +801,7 @@ class PlaygroundView(HTMLMixin, RenderableView):
                         '<strong>%(error)s</strong>.',
                         error = str(err)
                     )),
-                    hawat.const.HAWAT_FLASH_FAILURE
+                    vial.const.FLASH_FAILURE
                 )
 
                 tbexc = traceback.TracebackException(*sys.exc_info())
@@ -846,26 +821,14 @@ class PlaygroundView(HTMLMixin, RenderableView):
 #-------------------------------------------------------------------------------
 
 
-class FiltersBlueprint(HawatBlueprint):
-    """
-    Hawat pluggable module - reporting filters.
-    """
+class FiltersBlueprint(VialBlueprint):
+    """Pluggable module - reporting filter management (*filters*)."""
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.HawatBlueprint.get_module_title`."""
         return lazy_gettext('Reporting filter management pluggable module')
 
     def register_app(self, app):
-        """
-        *Callback method*. Will be called from :py:func:`hawat.base.HawatApp.register_blueprint`
-        method and can be used to customize the Flask application object. Possible
-        use cases:
-
-        * application menu customization
-
-        :param hawat.base.HawatApp app: Flask application to be customize.
-        """
         app.menu_main.add_entry(
             'view',
             'admin.{}'.format(BLUEPRINT_NAME),
@@ -886,8 +849,9 @@ class FiltersBlueprint(HawatBlueprint):
 
 def get_blueprint():
     """
-    Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.HawatBlueprint` or :py:class:`flask.Blueprint`.
+    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
+    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    :py:class:`flask.Blueprint`.
     """
 
     hbp = FiltersBlueprint(
@@ -897,14 +861,14 @@ def get_blueprint():
         url_prefix = '/{}'.format(BLUEPRINT_NAME)
     )
 
-    hbp.register_view_class(ListView, '/list')
-    hbp.register_view_class(CreateView, '/create')
-    hbp.register_view_class(CreateForView, '/createfor/<int:parent_id>')
-    hbp.register_view_class(ShowView, '/<int:item_id>/show')
-    hbp.register_view_class(UpdateView, '/<int:item_id>/update')
-    hbp.register_view_class(EnableView, '/<int:item_id>/enable')
-    hbp.register_view_class(DisableView, '/<int:item_id>/disable')
-    hbp.register_view_class(DeleteView, '/<int:item_id>/delete')
+    hbp.register_view_class(ListView,       '/list')
+    hbp.register_view_class(CreateView,     '/create')
+    hbp.register_view_class(CreateForView,  '/createfor/<int:parent_id>')
+    hbp.register_view_class(ShowView,       '/<int:item_id>/show')
+    hbp.register_view_class(UpdateView,     '/<int:item_id>/update')
+    hbp.register_view_class(EnableView,     '/<int:item_id>/enable')
+    hbp.register_view_class(DisableView,    '/<int:item_id>/disable')
+    hbp.register_view_class(DeleteView,     '/<int:item_id>/delete')
     hbp.register_view_class(PlaygroundView, '/playground')
 
     return hbp
