@@ -21,7 +21,7 @@ import wtforms
 import flask_wtf
 from flask_babel import lazy_gettext
 
-import hawat.forms
+import vial.forms
 
 
 class NerdSearchForm(flask_wtf.FlaskForm):
@@ -32,7 +32,7 @@ class NerdSearchForm(flask_wtf.FlaskForm):
         lazy_gettext('Search NERD:'),
         validators = [
             wtforms.validators.DataRequired(),
-            hawat.forms.check_ip4_record
+            vial.forms.check_ip4_record
         ]
     )
     submit = wtforms.SubmitField(
