@@ -9,11 +9,7 @@
 
 
 """
-Description
------------
-
-This pluggable module provides access to event reports.
-
+This pluggable module provides access to periodical event reports.
 """
 
 
@@ -21,15 +17,12 @@ __author__ = "Jan Mach <jan.mach@cesnet.cz>"
 __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"
 
 
+import re
 import os.path
 import datetime
 import dateutil.parser
 import pytz
-import re
 
-#
-# Flask related modules.
-#
 from jinja2.loaders import ChoiceLoader, FileSystemLoader
 import flask
 from flask.helpers import locked_cached_property
@@ -38,19 +31,19 @@ import flask_principal
 import flask_mail
 from flask_babel import gettext, lazy_gettext, force_locale, format_datetime
 
-#
-# Custom modules.
-#
 import mentat.const
 import mentat.stats.idea
-from mentat.datatype.sqldb import EventReportModel, GroupModel, UserModel
+from mentat.datatype.sqldb import EventReportModel, GroupModel, UserModel, ItemChangeLogModel
 from mentat.const import tr_
 
-import hawat.menu
-import hawat.acl
-from hawat.base import HTMLMixin, SQLAlchemyMixin, AJAXMixin, BaseSearchView, \
-    ItemShowView, ItemDeleteView, FileIdView, HawatBlueprint,\
-    URLParamsBuilder, RenderableView
+import hawat.const
+
+import vial.menu
+import vial.acl
+from vial.app import VialBlueprint
+from vial.view import RenderableView, FileIdView, BaseSearchView, ItemShowView, ItemDeleteView
+from vial.view.mixin import HTMLMixin, AJAXMixin, SQLAlchemyMixin
+from vial.utils import URLParamsBuilder
 from hawat.blueprints.reports.forms import EventReportSearchForm, ReportingDashboardForm, \
     FeedbackForm
 
@@ -95,7 +88,7 @@ def adjust_query_for_groups(query, groups):
         return query.join(GroupModel).filter(GroupModel.id.in_([grp.id for grp in groups]))
 
     # For non-administrators restrict query only to groups they are member of.
-    if not flask_login.current_user.has_role(hawat.const.HAWAT_ROLE_ADMIN):
+    if not flask_login.current_user.has_role(vial.const.ROLE_ADMIN):
         # Naive approach.
         #query = query.filter(model.group.has(GroupModel.members.any(UserModel.id == flask_login.current_user.id)))
         # "Joined" approach.
@@ -112,37 +105,30 @@ class SearchView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disable
 
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
-    def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
-        return lazy_gettext('Reports')
+    def get_view_icon(cls):
+        return 'module-{}'.format(cls.module_name)
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Search event reports')
 
-    #---------------------------------------------------------------------------
+    @classmethod
+    def get_menu_title(cls, **kwargs):
+        return lazy_gettext('Reports')
 
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return EventReportModel
 
     @staticmethod
     def get_search_form(request_args):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.get_search_form`.
-        """
         return EventReportSearchForm(request_args, meta = {'csrf': False})
 
     @staticmethod
     def build_query(query, model, form_args):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SQLAlchemyMixin.build_query`.
-        """
         # Adjust query based on group selection.
         query = adjust_query_for_groups(query, form_args.get('groups', None))
         # Adjust query based on text search string.
@@ -165,9 +151,6 @@ class SearchView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disable
         return query.order_by(model.createtime.desc()).order_by(model.label.desc())
 
     def do_after_search(self, items):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.do_after_search`.
-        """
         if items:
             self.response_context.update(
                 max_evcount_rep = max([x.evcount_rep for x in items])
@@ -184,49 +167,38 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
 
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Show report')
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """
-        *Interface implementation* of :py:func:`hawat.base.BaseView.get_menu_legend`.
-        """
-        return lazy_gettext('View details of event report &quot;%(item)s&quot;', item = str(kwargs['item']))
+        return lazy_gettext(
+            'View details of event report &quot;%(item)s&quot;',
+            item = flask.escape(str(kwargs['item']))
+        )
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Show report')
 
-    #---------------------------------------------------------------------------
-
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return EventReportModel
 
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        *Interface implementation* of :py:func:`hawat.base.ItemShowView.authorize_item_action`.
-        """
         permission_mm = flask_principal.Permission(
-            hawat.acl.MembershipNeed(kwargs['item'].group.id),
-            hawat.acl.ManagementNeed(kwargs['item'].group.id)
+            vial.acl.MembershipNeed(kwargs['item'].group.id),
+            vial.acl.ManagementNeed(kwargs['item'].group.id)
         )
-        return hawat.acl.PERMISSION_POWER.can() or permission_mm.can()
+        return vial.acl.PERMISSION_POWER.can() or permission_mm.can()
 
     @classmethod
     def get_breadcrumbs_menu(cls):  # pylint: disable=locally-disabled,unused-argument
-        """
-        *Interface implementation* of :py:func:`hawat.base.ItemShowView.get_breadcrumbs_menu`.
-        """
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'home',
-            endpoint = flask.current_app.config['HAWAT_ENDPOINT_HOME']
+            endpoint = flask.current_app.config['ENDPOINT_HOME']
         )
         action_menu.add_entry(
             'endpoint',
@@ -242,16 +214,13 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
 
     @classmethod
     def get_action_menu(cls):
-        """
-        *Interface implementation* of :py:func:`hawat.base.ItemShowView.get_action_menu`.
-        """
-        action_menu = hawat.menu.Menu()
+        action_menu = vial.menu.Menu()
         action_menu.add_entry(
             'endpoint',
             'search',
             endpoint = 'events.search',
             title = lazy_gettext('Search'),
-            legend = lambda **x: lazy_gettext('Search for all events related to report &quot;%(item)s&quot;', item = x['item'].label),
+            legend = lambda **x: lazy_gettext('Search for all events related to report &quot;%(item)s&quot;', item = flask.escape(x['item'].label)),
             url = lambda **x: flask.url_for('events.search', **build_related_search_params(x['item']))
         )
         action_menu.add_entry(
@@ -278,7 +247,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
             'endpoint',
             'more.downloadcsv',
             endpoint = 'reports.data',
-            title = lazy_gettext('Download data in CSV format'),
+            title = lazy_gettext('Download data in CSV format (deprecated)'),
             url = lambda **x: flask.url_for('reports.data', fileid = x['item'].label, filetype = 'csv'),
             hidelegend = True
         )
@@ -295,7 +264,7 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
             'endpoint',
             'more.downloadcsvzip',
             endpoint = 'reports.data',
-            title = lazy_gettext('Download compressed data in CSV format'),
+            title = lazy_gettext('Download compressed data in CSV format (deprecated)'),
             url = lambda **x: flask.url_for('reports.data', fileid = x['item'].label, filetype = 'csvzip'),
             icon = 'action-download-zip',
             hidelegend = True
@@ -315,35 +284,36 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
         )
 
     @staticmethod
-    def format_datetime(val, format, tzone):
+    def format_datetime_wz(val, format_str, tzone):
         """
         Static method that take string with isoformat datetime in utc and return
         string with BABEL_RFC3339_FORMAT formated datetime in tz timezone
         """
         return format_datetime(
             dateutil.parser.parse(val).replace(tzinfo=pytz.utc).astimezone(tzone),
-            format,
+            format_str,
             rebase = False
         )
 
     @staticmethod
-    def escape_id(id):
+    def escape_id(ident):
         """
         Escape id for use in bootstrap
         """
-        return re.sub(r"[^A-Za-z0-9-_]", (lambda x: '\{:X} '.format(ord(x.group()))), id)
+        return re.sub(r"[^A-Za-z0-9-_]", (lambda x: '\{:X} '.format(ord(x.group()))), ident)
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
         if 'item' in self.response_context and self.response_context['item']:
             self.response_context.update(
-                statistics        = self.response_context['item'].statistics,
-                template_vars     = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_TEMPLATEVARS],
-                form              = FeedbackForm(),
-                format_datetime   = ShowView.format_datetime,
-                tz                = pytz.timezone(self.response_context['item'].structured_data["timezone"]) if self.response_context['item'].structured_data else None,
-                event_classes_dir = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_EVENTCLASSESDIR],
-                escape_id        = ShowView.escape_id
+                statistics         = self.response_context['item'].statistics,
+                template_vars      = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_TEMPLATEVARS],
+                form               = FeedbackForm(),
+                format_datetime    = ShowView.format_datetime,
+                format_datetime_wz = ShowView.format_datetime_wz,
+                tz                 = pytz.timezone(self.response_context['item'].structured_data["timezone"]) if self.response_context['item'].structured_data else None,
+                tz_utc             = pytz.utc,
+                event_classes_dir  = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_EVENTCLASSESDIR],
+                escape_id          = ShowView.escape_id
             )
 
 
@@ -357,26 +327,18 @@ class UnauthShowView(ShowView):  # pylint: disable=locally-disabled,too-many-anc
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'unauth'
 
     @classmethod
     def get_view_template(cls):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.get_view_template`."""
         return '{}/show.html'.format(cls.module_name)
 
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        """
-        *Interface implementation* of :py:func:`hawat.base.ItemShowView.authorize_item_action`.
-        """
         return True
 
     @property
     def search_by(self):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SQLAlchemyMixin.search_by`.
-        """
         return self.dbmodel.label
 
 
@@ -390,19 +352,14 @@ class DataView(FileIdView):
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'data'
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Event report data')
 
     @classmethod
     def get_directory_path(cls, fileid, filetype):
-        """
-        *Interface implementation* of :py:func:`hawat.base.FileIdView.get_directory_path`.
-        """
         return mentat.const.construct_report_dirpath(
             flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_REPORTSDIR],
             fileid,
@@ -410,9 +367,6 @@ class DataView(FileIdView):
         )
 
     def get_filename(self, fileid, filetype):
-        """
-        *Interface implementation* of :py:func:`hawat.base.FileIdView.get_filename`.
-        """
         fileext = ''
         if filetype == 'json':
             fileext = 'json'
@@ -433,47 +387,38 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disa
     """
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'dashboard'
 
+    @classmethod
+    def get_view_icon(cls):
+        return 'module-{}'.format(cls.module_name)
+
     @classmethod
     def get_menu_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Reporting')
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_title`."""
         return lazy_gettext('Event reporting dashboards')
 
     @classmethod
     def get_view_template(cls):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.get_view_template`."""
         return '{}/dashboard.html'.format(cls.module_name)
 
-    #---------------------------------------------------------------------------
-
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return EventReportModel
 
     @staticmethod
     def get_search_form(request_args):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.get_search_form`.
-        """
         return ReportingDashboardForm(request_args, meta = {'csrf': False})
 
     @staticmethod
     def build_query(query, model, form_args):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SQLAlchemyMixin.build_query`.
-        """
         # Adjust query based on group selection.
         query = adjust_query_for_groups(query, form_args.get('groups', None))
         # Adjust query based on lower time boudary selection.
@@ -487,9 +432,6 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disa
         return query.order_by(model.label)
 
     def do_after_search(self, items):
-        """
-        *Interface implementation* of :py:func:`hawat.base.SearchView.do_after_search`.
-        """
         self.logger.debug(
             "Calculating event reporting dashboard overview from %d records.",
             len(items)
@@ -516,7 +458,6 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disa
             )
 
     def do_before_response(self, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.RenderableView.do_before_response`."""
         self.response_context.update(
             quicksearch_list = self.get_quicksearch_by_time()
         )
@@ -530,44 +471,48 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
 
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ADMIN]
+    authorization = [vial.acl.PERMISSION_ADMIN]
 
     @classmethod
     def get_menu_legend(cls, **kwargs):
-        """
-        *Interface implementation* of :py:func:`hawat.base.BaseView.get_menu_legend`.
-        """
-        return lazy_gettext('Delete event report &quot;%(item)s&quot;', item = str(kwargs['item']))
+        return lazy_gettext(
+            'Delete event report &quot;%(item)s&quot;',
+            item = flask.escape(str(kwargs['item']))
+        )
 
     def get_url_next(self):
-        """
-        *Interface implementation* of :py:func:`hawat.base.ItemActionView.get_url_next`.
-        """
-        return flask.url_for('{}.{}'.format(self.module_name, 'search'))
-
-    #---------------------------------------------------------------------------
+        return flask.url_for(
+            '{}.{}'.format(self.module_name, 'search')
+        )
 
     @property
     def dbmodel(self):
-        """*Implementation* of :py:func:`hawat.base.SQLAlchemyMixin.dbmodel`."""
         return EventReportModel
 
-    #---------------------------------------------------------------------------
+    @property
+    def dbchlogmodel(self):
+        return ItemChangeLogModel
 
     @staticmethod
     def get_message_success(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_success`."""
-        return gettext('Event report <strong>%(item_id)s</strong> was successfully and permanently deleted.', item_id = str(kwargs['item']))
+        return gettext(
+            'Event report <strong>%(item_id)s</strong> was successfully and permanently deleted.',
+            item_id = flask.escape(str(kwargs['item']))
+        )
 
     @staticmethod
     def get_message_failure(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_failure`."""
-        return gettext('Unable to delete event report <strong>%(item_id)s</strong>.', item_id = str(kwargs['item']))
+        return gettext(
+            'Unable to delete event report <strong>%(item_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item']))
+        )
 
     @staticmethod
     def get_message_cancel(**kwargs):
-        """*Implementation* of :py:func:`hawat.base.ItemActionView.get_message_cancel`."""
-        return gettext('Canceled deleting event report <strong>%(item_id)s</strong>.', item_id = str(kwargs['item']))
+        return gettext(
+            'Canceled deleting event report <strong>%(item_id)s</strong>.',
+            item_id = flask.escape(str(kwargs['item']))
+        )
 
 
 class FeedbackView(AJAXMixin, RenderableView):
@@ -578,20 +523,16 @@ class FeedbackView(AJAXMixin, RenderableView):
 
     authentication = True
 
-    authorization = [hawat.acl.PERMISSION_ANY]
+    authorization = [vial.acl.PERMISSION_ANY]
 
     @classmethod
     def get_view_name(cls):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_view_name`."""
         return 'feedback'
 
     @classmethod
     def get_view_title(cls, **kwargs):
-        """*Implementation* of :py:func:`hawat.base.BaseView.get_menu_title`."""
         return lazy_gettext('Report feedback')
 
-    #---------------------------------------------------------------------------
-
     def dispatch_request(self, item_id):  # pylint: disable=locally-disabled,arguments-differ
         """
         Mandatory interface required by the :py:func:`flask.views.View.dispatch_request`.
@@ -632,29 +573,18 @@ class FeedbackView(AJAXMixin, RenderableView):
             self.response_context["message"] = "<br />".join([": ".join(err) for err in self.response_context["form_errors"]])
         return self.generate_response()
 
+
 #-------------------------------------------------------------------------------
 
 
-class ReportsBlueprint(HawatBlueprint):
-    """
-    Hawat pluggable module - event reports.
-    """
+class ReportsBlueprint(VialBlueprint):
+    """Pluggable module - periodical event reports (*reports*)."""
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.HawatBlueprint.get_module_title`."""
         return lazy_gettext('Event reports')
 
     def register_app(self, app):
-        """
-        *Callback method*. Will be called from :py:func:`hawat.base.HawatApp.register_blueprint`
-        method and can be used to customize the Flask application object. Possible
-        use cases:
-
-        * application menu customization
-
-        :param hawat.base.HawatApp app: Flask application to be customize.
-        """
         app.menu_main.add_entry(
             'view',
             'dashboards.reporting',
@@ -671,14 +601,14 @@ class ReportsBlueprint(HawatBlueprint):
 
         # Register context actions provided by this module.
         app.set_csag(
-            hawat.const.HAWAT_CSAG_ABUSE,
+            hawat.const.CSAG_ABUSE,
             tr_('Search for abuse group <strong>%(name)s</strong> in report database'),
             SearchView,
             URLParamsBuilder({'submit': tr_('Search')}).add_rule('groups', True).add_kwrule('dt_from', False, True).add_kwrule('dt_to', False, True)
         )
 
         app.set_csag(
-            hawat.const.HAWAT_CSAG_ABUSE,
+            hawat.const.CSAG_ABUSE,
             tr_('Search for abuse group <strong>%(name)s</strong> in reporting dashboards'),
             DashboardView,
             URLParamsBuilder({'submit': tr_('Search')}).add_rule('groups', True).add_kwrule('dt_from', False, True).add_kwrule('dt_to', False, True)
@@ -699,8 +629,9 @@ class ReportsBlueprint(HawatBlueprint):
 
 def get_blueprint():
     """
-    Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.HawatBlueprint` or :py:class:`flask.Blueprint`.
+    Mandatory interface for :py:mod:`vial.Vial` and factory function. This function
+    must return a valid instance of :py:class:`vial.app.VialBlueprint` or
+    :py:class:`flask.Blueprint`.
     """
 
     hbp = ReportsBlueprint(
@@ -710,12 +641,12 @@ def get_blueprint():
         url_prefix = '/{}'.format(BLUEPRINT_NAME)
     )
 
-    hbp.register_view_class(SearchView, '/search')
-    hbp.register_view_class(ShowView, '/<int:item_id>/show')
+    hbp.register_view_class(SearchView,     '/search')
+    hbp.register_view_class(ShowView,       '/<int:item_id>/show')
     hbp.register_view_class(UnauthShowView, '/<item_id>/unauth')
-    hbp.register_view_class(DataView, '/data/<fileid>/<filetype>')
-    hbp.register_view_class(DashboardView, '/dashboard')
-    hbp.register_view_class(DeleteView, '/<int:item_id>/delete')
-    hbp.register_view_class(FeedbackView, '/<item_id>/feedback')
+    hbp.register_view_class(DataView,       '/data/<fileid>/<filetype>')
+    hbp.register_view_class(DashboardView,  '/dashboard')
+    hbp.register_view_class(DeleteView,     '/<int:item_id>/delete')
+    hbp.register_view_class(FeedbackView,   '/<item_id>/feedback')
 
     return hbp
