@@ -277,7 +277,7 @@ class TestMentatStorage(unittest.TestCase):
 
         orig = json.dumps(idea_into, indent=4, sort_keys=True, default=idea_into.json_default)
         new  = json.dumps(idea_from, indent=4, sort_keys=True, default=idea_from.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         idea_from = storage.fetch_event(idea_into['ID'])
         self.assertTrue(idea_from)
@@ -292,7 +292,7 @@ class TestMentatStorage(unittest.TestCase):
 
         orig = json.dumps(idea_into, indent=4, sort_keys=True, default=idea_into.json_default)
         new  = json.dumps(idea_from, indent=4, sort_keys=True, default=idea_from.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         idea_from = storage.fetch_event(idea_into['ID'])
         self.assertTrue(idea_from)
@@ -818,7 +818,144 @@ class TestMentatStorage(unittest.TestCase):
         storage.database_drop()
         storage.close()
 
-    def test_06_search_events(self):
+    def test_06_build_query_aggr(self):
+        """
+        Perform various query building tests.
+        """
+        self.maxDiff = None
+
+        storage = self._get_clean_storage()
+
+        tests = [
+            (
+                {
+                    'parameters': {},
+                    'qtype': 'aggregate'
+                },
+                b'SELECT COUNT(*) FROM events'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7)
+                    },
+                    'qtype': 'aggregate'
+                },
+                b'SELECT COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                    },
+                    'qtype': 'aggregate'
+                },
+                b'SELECT COUNT(*) FROM events WHERE "detecttime" <= \'2012-11-03T10:00:07\'::timestamp'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                    },
+                    'qtype': 'aggregate'
+                },
+                b'SELECT COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'aggr_set': 'cesnet_eventclass',
+                    },
+                    'qtype': 'aggregate'
+                },
+                b'SELECT "cesnet_eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'aggr_set': 'category',
+                    },
+                    'qtype': 'aggregate'
+                },
+                b'SELECT unnest("category") AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'aggr_set': 'cesnet_eventclass',
+                        'limit': 10
+                    },
+                    'qtype': 'aggregate'
+                },
+                b'SELECT "cesnet_eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'aggr_set': 'category',
+                        'limit': 10
+                    },
+                    'qtype': 'aggregate'
+                },
+                b'SELECT unnest("category") AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 12, 3, 10, 0, 7),
+                        'step': datetime.timedelta(days = 1),
+                    },
+                    'qtype': 'timeline'
+                },
+                b'SELECT \'2012-11-03T10:00:07\'::timestamp + \'1 days 0.000000 seconds\'::interval * (width_bucket(detecttime,(SELECT array_agg(buckets) FROM generate_series(\'2012-11-03T10:00:07\'::timestamp,\'2012-12-03T10:00:07\'::timestamp,\'1 days 0.000000 seconds\'::interval) AS buckets)) - 1) AS bucket,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-12-03T10:00:07\'::timestamp GROUP BY bucket ORDER BY bucket ASC'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 12, 3, 10, 0, 7),
+                        'step': datetime.timedelta(days = 1),
+                        'aggr_set': 'cesnet_eventclass',
+                    },
+                    'qtype': 'timeline'
+                },
+                b'SELECT \'2012-11-03T10:00:07\'::timestamp + \'1 days 0.000000 seconds\'::interval * (width_bucket(detecttime,(SELECT array_agg(buckets) FROM generate_series(\'2012-11-03T10:00:07\'::timestamp,\'2012-12-03T10:00:07\'::timestamp,\'1 days 0.000000 seconds\'::interval) AS buckets)) - 1) AS bucket,"cesnet_eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-12-03T10:00:07\'::timestamp GROUP BY bucket, set ORDER BY bucket ASC'
+            ),
+            (
+                {
+                    'parameters': {
+                        'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
+                        'dt_to': datetime.datetime(2012, 12, 3, 10, 0, 7),
+                        'step': datetime.timedelta(days = 1),
+                        'aggr_set': 'category',
+                    },
+                    'qtype': 'timeline'
+                },
+                b'SELECT \'2012-11-03T10:00:07\'::timestamp + \'1 days 0.000000 seconds\'::interval * (width_bucket(detecttime,(SELECT array_agg(buckets) FROM generate_series(\'2012-11-03T10:00:07\'::timestamp,\'2012-12-03T10:00:07\'::timestamp,\'1 days 0.000000 seconds\'::interval) AS buckets)) - 1) AS bucket,unnest("category") AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-12-03T10:00:07\'::timestamp GROUP BY bucket, set ORDER BY bucket ASC'
+            ),
+        ]
+
+        for test in tests:
+            query, params = mentat.services.eventstorage.build_query(**test[0])
+            self.assertEqual(
+                str(storage.mogrify(query, params)).replace(', ', ','),
+                str(test[1]).replace(', ', ',')
+            )
+
+        storage.database_drop()
+        storage.close()
+
+    def test_07_search_events(self):
         """
         Perform various event search tests.
         """
@@ -840,7 +977,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -861,7 +998,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -882,7 +1019,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -893,7 +1030,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -904,7 +1041,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -925,7 +1062,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -936,7 +1073,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -947,7 +1084,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -967,7 +1104,7 @@ class TestMentatStorage(unittest.TestCase):
             }
         )
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -978,7 +1115,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -999,7 +1136,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1020,7 +1157,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1031,7 +1168,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1052,7 +1189,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1073,7 +1210,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1094,7 +1231,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1115,7 +1252,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1136,7 +1273,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1157,7 +1294,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1178,7 +1315,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1199,7 +1336,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1220,7 +1357,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1241,7 +1378,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1262,7 +1399,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1283,7 +1420,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1304,7 +1441,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1325,7 +1462,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1346,7 +1483,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 1)
         new  = json.dumps(ideas_from, indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         # ---
 
@@ -1363,7 +1500,7 @@ class TestMentatStorage(unittest.TestCase):
         #storage.database_drop()
         storage.close()
 
-    def test_07_watchdog_events(self):
+    def test_08_watchdog_events(self):
         """
         Perform event database watchdog tests.
         """
@@ -1388,7 +1525,7 @@ class TestMentatStorage(unittest.TestCase):
         self.assertTrue(storage.watchdog_events(900))
 
 
-    def test_08_count_events(self):
+    def test_09_count_events(self):
         """
         Perform various event count tests.
         """
@@ -1435,7 +1572,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 0)
 
-    def test_09_delete_events(self):
+    def test_10_delete_events(self):
         """
         Perform various event delete tests.
         """
@@ -1484,7 +1621,7 @@ class TestMentatStorage(unittest.TestCase):
         )
         self.assertEqual(ideas_count, 0)
 
-    def test_10_distinct_values(self):
+    def test_11_distinct_values(self):
         """
         Perform various distinct values tests.
         """
@@ -1499,7 +1636,7 @@ class TestMentatStorage(unittest.TestCase):
         self.assertEqual(ideas_count, 1)
         orig = json.dumps(idea_into, indent=4, sort_keys=True, default=idea_into.json_default)
         new  = json.dumps(ideas_from[0], indent=4, sort_keys=True, default=idea_into.json_default)
-        self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
+        self.assertEqual(orig, new, "\n".join(difflib.context_diff(orig.split("\n"), new.split("\n"))))
 
         self.assertEqual(
             storage.distinct_values('category'),
@@ -1516,7 +1653,7 @@ class TestMentatStorage(unittest.TestCase):
             ['low']
         )
 
-    def test_11_thresholding_cache(self):
+    def test_12_thresholding_cache(self):
         """
         Perform various thresholding cache tests.
         """
@@ -1559,7 +1696,7 @@ class TestMentatStorage(unittest.TestCase):
         self.assertEqual(storage.thresholds_count(), 0)
         self.assertEqual(storage.thresholded_events_count(), 0)
 
-    def test_12_relapse(self):
+    def test_13_relapse(self):
         """
         Perform various relapse tests.
         """
@@ -1610,7 +1747,7 @@ class TestMentatStorage(unittest.TestCase):
         count = storage.delete_events()
         self.assertEqual(count, 1)
 
-    def test_12_search_event_ghosts(self):
+    def test_14_search_event_ghosts(self):
         """
         Perform various event search tests.
         """
