@@ -47,12 +47,19 @@ ST_SKEY_CATEGORIES  = 'categories'
 ST_SKEY_CATEGSETS   = 'category_sets'
 ST_SKEY_DETECTORS   = 'detectors'
 ST_SKEY_DETECTORSWS = 'detectorsws'
+ST_SKEY_DETECTORTPS = 'detector_types'
 ST_SKEY_ABUSES      = 'abuses'
 ST_SKEY_EMAILS      = 'emails'
 ST_SKEY_ASNS        = 'asns'
 ST_SKEY_COUNTRIES   = 'countries'
 ST_SKEY_CLASSES     = 'classes'
 ST_SKEY_SEVERITIES  = 'severities'
+ST_SKEY_PORTS       = 'ports'
+ST_SKEY_SRCPORTS    = 'source_ports'
+ST_SKEY_TGTPORTS    = 'target_ports'
+ST_SKEY_SRCTYPES    = 'source_types'
+ST_SKEY_TGTTYPES    = 'target_types'
+ST_SKEY_PROTOCOLS   = 'protocols'
 ST_SKEY_LIST_IDS    = 'list_ids'
 ST_SKEY_CNT_ALERTS  = 'cnt_alerts'
 ST_SKEY_CNT_EVENTS  = 'cnt_events'
@@ -110,6 +117,10 @@ TRUNCATION_WHITELIST = {
     ST_SKEY_CATEGSETS:   True,
     ST_SKEY_DETECTORS:   True,
     ST_SKEY_DETECTORSWS: True,
+    ST_SKEY_DETECTORTPS: True,
+    ST_SKEY_SRCTYPES:    True,
+    ST_SKEY_TGTTYPES:    True,
+    ST_SKEY_PROTOCOLS:   True,
     ST_SKEY_ABUSES:      True,
     ST_SKEY_COUNTRIES:   True,
     ST_SKEY_CLASSES:     True,
@@ -124,15 +135,25 @@ TRUNCATION_WHITELIST_THRESHOLD = 1000
 """Threshold for whitelisted truncated statistics."""
 
 LIST_CALCSTAT_KEYS = tuple(
-    [x[0] for x in LIST_AGGREGATIONS] + [ST_SKEY_CATEGSETS, ST_SKEY_DETECTORSWS]
+    [x[0] for x in LIST_AGGREGATIONS] + [
+        ST_SKEY_CATEGSETS,
+        ST_SKEY_DETECTORSWS,
+        ST_SKEY_DETECTORTPS,
+        ST_SKEY_SRCTYPES,
+        ST_SKEY_TGTTYPES,
+        ST_SKEY_SRCPORTS,
+        ST_SKEY_TGTPORTS,
+        ST_SKEY_PROTOCOLS
+    ]
 )
 """List of subkey names of all calculated statistics."""
 
 
 LIST_OPTIMAL_STEPS = (
-    1,      2,      3,      4,      5,      6,      10,      12,      15,      20,      30,     # seconds
-    1*60,   2*60,   3*60,   4*60,   5*60,   6*60,   10*60,   12*60,   15*60,   20*60,   30*60,  # minutes
-    1*3600, 2*3600, 3*3600, 4*3600, 6*3600, 8*3600, 12*3600, 24*3600, 48*3600, 72*3600, 96*3600 # hours
+    1,         2,         3,         4,         5,         6,         10,         12,         15,        20,    30,     # seconds
+    1*60,      2*60,      3*60,      4*60,      5*60,      6*60,      10*60,      12*60,      15*60,     20*60, 30*60,  # minutes
+    1*3600,    2*3600,    3*3600,    4*3600,    6*3600,    8*3600,    12*3600,                                          # hours
+    1*24*3600, 2*24*3600, 3*24*3600, 4*24*3600, 5*24*3600, 6*24*3600,  7*24*3600, 10*24*3600, 14*24*3600                # days
 )
 """List of optimal timeline steps. This list is populated with values, that round nicelly in time calculations."""
 
@@ -164,6 +185,7 @@ def truncate_stats(stats, top_threshold = TRUNCATION_THRESHOLD, force = False):
 
     return stats
 
+
 def truncate_stats_with_mask(stats, mask, top_threshold = TRUNCATION_THRESHOLD, force = False):
     """
     Make statistics more brief. For each of the statistical aggregation subkeys
@@ -194,6 +216,7 @@ def truncate_stats_with_mask(stats, mask, top_threshold = TRUNCATION_THRESHOLD,
 
     return stats
 
+
 def truncate_evaluations(stats, top_threshold = TRUNCATION_THRESHOLD, force = False):
     """
     Make all statistical groups more brief with :py:func:`truncate_stats`.
@@ -249,6 +272,7 @@ def evaluate_events(events, stats = None):
 
     return stats
 
+
 def evaluate_timeline_events(events, dt_from, dt_to, max_count, stats = None):
     """
     Evaluate statistics for given list of IDEA events and produce statistical
@@ -285,7 +309,7 @@ def evaluate_timeline_events(events, dt_from, dt_to, max_count, stats = None):
 
     for event in events:
         # Detect recurring events.
-        recurring = tcache.event_is_thresholded(event, None)
+        recurring = tcache.event_is_thresholded(event, None, None)
         tcache.set_threshold(event, None, None, None, None)
 
         # Include event into global statistics.
@@ -309,6 +333,7 @@ def evaluate_timeline_events(events, dt_from, dt_to, max_count, stats = None):
 
     return stats
 
+
 def evaluate_singlehost_events(host, events, dt_from, dt_to, max_count, stats = None):
     """
     Evaluate statistics for given list of IDEA events and produce statistical
@@ -346,7 +371,7 @@ def evaluate_singlehost_events(host, events, dt_from, dt_to, max_count, stats =
 
     for event in events:
         # Detect recurring events.
-        recurring = tcache.event_is_thresholded(event, None)
+        recurring = tcache.event_is_thresholded(event, None, None)
         tcache.set_threshold(event, None, None, None, None)
 
         # Include event into global statistics.
@@ -370,6 +395,7 @@ def evaluate_singlehost_events(host, events, dt_from, dt_to, max_count, stats =
 
     return stats
 
+
 def aggregate_stats_reports(report_list, dt_from, dt_to, result = None):
     """
     Aggregate multiple reporting statistical records.
@@ -428,6 +454,79 @@ def aggregate_stats_reports(report_list, dt_from, dt_to, result = None):
     return result
 
 
+def aggregate_dbstats_events(aggr_type, aggr_name, aggr_data, default_val, timeline_cfg, result = None):
+    """
+
+    """
+    if result is None:
+        result = dict()
+
+    if aggr_type == 'timeline':
+        bucket_dict = { bucket: idx for idx, bucket in enumerate(timeline_cfg['buckets']) }
+        result.setdefault(
+            ST_SKEY_TIMELINE,
+            [
+                [x, {}] for x in timeline_cfg['buckets']
+            ]
+        )
+
+    if aggr_data:
+        if aggr_type == 'aggregate':
+            for res in aggr_data:
+                if hasattr(res, 'set'):
+                    result.setdefault(aggr_name, {})[str(res.set) or KEY_UNKNOWN] = res.count
+                else:
+                    result[aggr_name] = res.count
+
+        elif aggr_type == 'timeline':
+            for res in aggr_data:
+                try:
+                    idx = bucket_dict[res.bucket]
+                    if hasattr(res, 'set'):
+                        result[ST_SKEY_TIMELINE][idx][1].setdefault(aggr_name, {})[str(res.set) or KEY_UNKNOWN] = res.count
+                    else:
+                        result[ST_SKEY_TIMELINE][idx][1][aggr_name] = res.count
+                except KeyError:
+                    raise ValueError(
+                        "Timeline bucket missmatch for '{}:{}:{}' [{}]".format(
+                            aggr_type,
+                            aggr_name,
+                            res.bucket,
+                            str(res.set)
+                        )
+                    )
+
+    elif aggr_type == 'aggregate':
+        result[aggr_name] = default_val
+
+    return result
+
+def postcalculate_dbstats_events(aggr_name, result):
+    """
+
+    """
+    for tlbucket in result[ST_SKEY_TIMELINE]:
+        if aggr_name in tlbucket[1]:
+            if isinstance(tlbucket[1][aggr_name], dict):
+                for key, value in tlbucket[1][aggr_name].items():
+                    _counter_inc(result, aggr_name, key, value)
+            else:
+                _counter_inc_one(result, aggr_name, tlbucket[1][aggr_name])
+
+def evaluate_dbstats_events(stats):
+    """
+
+    """
+    stats = truncate_stats(stats)
+
+    # Calculate secondary statistics and mask the result to toplist of given size
+    # for all timeline time windows.
+    for tl_stat in stats[ST_SKEY_TIMELINE]:
+        tl_stat[1] = truncate_stats_with_mask(tl_stat[1], stats)
+
+    return stats
+
+
 #-------------------------------------------------------------------------------
 
 
@@ -451,6 +550,7 @@ def group_events(events):
             result[ST_EXTERNAL].append(msg)
     return result
 
+
 def evaluate_event_groups(events, stats = None):
     """
     Evaluate full statistics for given list of IDEA events. Events will be
@@ -473,6 +573,7 @@ def evaluate_event_groups(events, stats = None):
         stats[grp_key] = evaluate_events(msg_groups.get(grp_key, []))
     return stats
 
+
 def aggregate_stat_groups(stats_list, result = None):
     """
     Aggregate multiple full statistical records produced by the
@@ -515,6 +616,7 @@ def aggregate_stat_groups(stats_list, result = None):
 
     return result
 
+
 def aggregate_timeline_groups(stats_list, dt_from, dt_to, max_count, min_step = None, result = None):
     """
     Aggregate multiple full statistical records produced by the
@@ -598,6 +700,47 @@ def aggregate_timeline_groups(stats_list, dt_from, dt_to, max_count, min_step =
     return result
 
 
+def calculate_timeline_config(dt_from, dt_to, max_count, min_step = None):
+    """
+    Calculate optimal configurations for timeline chart dataset.
+    """
+    dt_from, dt_to, delta = _calculate_timeline_boundaries(dt_from, dt_to)  # pylint: disable=locally-disabled,unused-variable
+    step, step_count = _calculate_timeline_steps(dt_from, dt_to, max_count, min_step)
+    return {
+        ST_SKEY_DT_FROM: dt_from,
+        ST_SKEY_DT_TO: dt_to,
+        'step': step,
+        'count': step_count
+    }
+
+
+def calculate_timeline_config_daily(dt_from, dt_to):
+    """
+    Calculate optimal configurations for timeline chart dataset with steps forced to one day.
+    """
+    step = datetime.timedelta(days = 1)
+    dt_from = dt_from.replace(
+        hour = 0,
+        minute = 0,
+        second = 0,
+        microsecond = 0
+    )
+    dt_to = dt_to.replace(
+        hour = 0,
+        minute = 0,
+        second = 0,
+        microsecond = 0
+    ) + step
+
+    step_count = int((dt_to - dt_from) / step)
+    return {
+        ST_SKEY_DT_FROM: dt_from,
+        ST_SKEY_DT_TO: dt_to,
+        'step': step,
+        'count': step_count
+    }
+
+
 #-------------------------------------------------------------------------------
 
 
@@ -621,6 +764,7 @@ def _counter_inc(stats, stat, key, increment = 1):
     stats[stat][str(key)] = stats[stat].get(str(key), 0) + increment
     return stats
 
+
 def _counter_inc_all(stats, stat, key_list, increment = 1):
     """
     Helper for incrementing multiple statistical parameters within given statistical
@@ -638,6 +782,27 @@ def _counter_inc_all(stats, stat, key_list, increment = 1):
             _counter_inc(stats, stat, key, increment)
     return stats
 
+def _counter_inc_one(stats, stat, increment = 1):
+    """
+    Helper for incrementing given statistical parameter within given statistical
+    bundle.
+
+    :param dict stats: Structure containing all statistics.
+    :param str stat: Name of the statistical category.
+    :param str key: Name of the statistical key.
+    :param int increment: Counter increment.
+    :return: Updated structure containing statistics.
+    :rtype: dict
+    """
+
+    # I have considered using setdefault() method, but the performance is worse
+    # in comparison with using if (measured with cProfile module).
+    if not stat in stats:
+        stats[stat] = 0
+    stats[stat] += increment
+    return stats
+
+
 def _include_event_to_stats(stats, event, recurring = False, skip = None):
     """
     Include given IDEA event into given statistical record.
@@ -680,6 +845,7 @@ def _include_event_to_stats(stats, event, recurring = False, skip = None):
             key = det
             _counter_inc(stats, ST_SKEY_DETECTORSWS, key)
 
+
 def _merge_stats(stats, result = None):
     """
     Merge given statistical record into given result record.
@@ -702,6 +868,7 @@ def _merge_stats(stats, result = None):
 
     return result
 
+
 def _include_report_to_stats(stats, report):
     """
     Merge given report statistical record into given result record.
@@ -750,6 +917,7 @@ def _include_report_to_stats(stats, report):
 
     return stats
 
+
 def _calculate_secondary_stats(stats):
     """
     Calculate common secondary statistics.
@@ -768,6 +936,7 @@ def _calculate_secondary_stats(stats):
 
     return stats
 
+
 def _make_toplist(stats, dict_key, top_threshold, force = False):
     """
     Produce only toplist of given statistical keys.
@@ -813,6 +982,7 @@ def _make_toplist(stats, dict_key, top_threshold, force = False):
 
     return stats
 
+
 def _mask_toplist(stats, mask, dict_key, top_threshold, force = False):
     """
     Produce only toplist of given statistical keys. Use global statistics as mask
@@ -862,6 +1032,7 @@ def _mask_toplist(stats, mask, dict_key, top_threshold, force = False):
 
     return stats
 
+
 def _calculate_timeline_boundaries(dt_from, dt_to):
     """
     Calculate optimal and rounded values for lower and upper timeline boundaries
@@ -921,6 +1092,7 @@ def _calculate_timeline_boundaries(dt_from, dt_to):
         delta_day
     )
 
+
 def _calculate_timeline_steps(dt_from, dt_to, max_count, min_step = None):
     """
     Calculate optimal timeline step/window from given optimal lower and upper
@@ -944,31 +1116,28 @@ def _calculate_timeline_steps(dt_from, dt_to, max_count, min_step = None):
 
     return (step, step_count)
 
+
 def _init_time_scatter():
     """
     Init structure for time scatter chart dataset.
     """
     return [[{} for y in range(24)] for x in range(7)]
 
+
 def _init_timeline(dt_from, dt_to, max_count, min_step = None):
     """
     Init structure for timeline chart dataset.
     """
-    dt_from, dt_to, delta = _calculate_timeline_boundaries(dt_from, dt_to)  # pylint: disable=locally-disabled,unused-variable
-    step, step_count = _calculate_timeline_steps(dt_from, dt_to, max_count, min_step)
-    timeline_cfg = {
-        ST_SKEY_DT_FROM: dt_from,
-        ST_SKEY_DT_TO: dt_to,
-        'step': step,
-        'count': step_count
-    }
+    timeline_cfg = calculate_timeline_config(dt_from, dt_to, max_count, min_step)
 
+    dt_from = timeline_cfg[ST_SKEY_DT_FROM]
     timeline = list()
-    for i in range(step_count):  # pylint: disable=locally-disabled,unused-variable
+    for i in range(timeline_cfg['count']):  # pylint: disable=locally-disabled,unused-variable
         timeline.append([dt_from, {}])
-        dt_from = dt_from + step
+        dt_from = dt_from + timeline_cfg['step']
     return timeline, timeline_cfg
 
+
 def _init_daily_timeline(dt_from, dt_to):
     """
     Init structure for timeline chart dataset with steps forced to one day. Given
@@ -979,30 +1148,11 @@ def _init_daily_timeline(dt_from, dt_to):
     :return: Tuple containing preinitialized timeline structure and dictionary describing final timeline configuration.
     :rtype: tuple
     """
-    step = datetime.timedelta(days = 1)
-    dt_from = dt_from.replace(
-        hour = 0,
-        minute = 0,
-        second = 0,
-        microsecond = 0
-    )
-    dt_to = dt_to.replace(
-        hour = 0,
-        minute = 0,
-        second = 0,
-        microsecond = 0
-    ) + step
-
-    step_count = int((dt_to - dt_from) / step)
-    timeline_cfg = {
-        ST_SKEY_DT_FROM: dt_from,
-        ST_SKEY_DT_TO: dt_to,
-        'step': step,
-        'count': step_count
-    }
+    timeline_cfg = calculate_timeline_config_daily(dt_from, dt_to)
 
+    dt_from = timeline_cfg[ST_SKEY_DT_FROM]
     timeline = list()
-    for i in range(step_count):  # pylint: disable=locally-disabled,unused-variable
+    for i in range(timeline_cfg['count']):  # pylint: disable=locally-disabled,unused-variable
         timeline.append([dt_from, {}])
-        dt_from = dt_from + step
+        dt_from = dt_from + timeline_cfg['step']
     return timeline, timeline_cfg
